@@ -22,6 +22,7 @@ int main(void)
     char *founddata;
     int pass = 0;
     unsigned int seed = 0U;
+    unsigned int randomrounds = 42000;
 
     printf("Starting regression tests\n\nDatabase creation (wait) ... ");
     fflush(stdout);
@@ -32,7 +33,7 @@ int main(void)
     seed = (unsigned int) time(NULL);
     srand(seed);
     do {
-        curkey += (rand() & 0x6fff);
+        curkey += (rand() & 0x4fff);
         snprintf(key, sizeof key, "%llu", curkey);
         snprintf(data, sizeof data, "%llu", curkey ^ 0x12345678abcdefULL);
         if (puredbw_add_s(&dbw, key, data) != 0) {
@@ -65,7 +66,7 @@ int main(void)
     curkey = 0ULL;    
     srand(seed);
     do {
-        curkey += (rand() & 0x6fff);
+        curkey += (rand() & 0x4fff);
         snprintf(key, sizeof key, "%llu", curkey);
         snprintf(data, sizeof data, "%llu", curkey ^ 0x12345678abcdefULL);
         if (puredb_find_s(&db, key, &retpos, &retlen) != 0) {
@@ -80,6 +81,18 @@ int main(void)
             puredb_read_free(founddata);
         }
     } while (curkey < 0xfffffff0);
+    printf("also trying non-existent data ... ");
+    fflush(stdout);
+    do {
+        curkey <<= 1;
+        curkey ^= (unsigned long long) rand();
+        snprintf(key, sizeof key, "%llu", curkey);
+        if (puredb_find_s(&db, key, &retpos, &retlen) == 0) {
+            founddata = puredb_read(&db, retpos, retlen);
+            puredb_read_free(founddata);
+        }
+        randomrounds--;
+    } while (randomrounds > 0U);
     pass++;
     end2:
     if (puredb_close(&db) != 0) {
@@ -90,7 +103,7 @@ int main(void)
         puts("Failure :(");
         return -1;
     } else {
-        printf("Success! %llu records have been fetched\n", nbrec);
+        puts("Success!");
     }
     
     return 0;
