@@ -125,13 +125,21 @@ static int fakexlate(char *curdirtmp, size_t sizeof_curdirtmp, const char *dir)
         size_t dirlen;
         size_t curdirtmplen;
         
-        if (strstr(dir, "..") != NULL) {
+        if ((dir[0] == '.' && dir[1] == '.' &&
+             (dir[2] == 0 || dir[2] == '/')) ||            
+            strstr(dir, "/../") != NULL) {
+            perm:
 # ifdef EPERM
             errno = EPERM;
 # endif
             return -1;
         }
-        dirlen = strlen(dir) + 1U;
+        dirlen = strlen(dir) + (size_t) 1U;
+        if (dirlen >= (size_t) 4U &&
+            (dir[dirlen - 2U] == '.' && dir[dirlen - 3U] == '.' &&
+             dir[dirlen - 4U] == '/')) {
+            goto perm;
+        }
         curdirtmplen = strlen(curdirtmp);
         if (curdirtmplen + dirlen >= sizeof_curdirtmp) {
 # ifdef ENAMETOOLONG
@@ -493,5 +501,6 @@ int fakestatfs(const char *path, STATFS_STRUCT *str)
     return STATFS(curdirtmp, str);
 }
 # endif
-
+#else
+extern signed char v6ready;
 #endif
