@@ -34,10 +34,12 @@ void ftpwho_exit(const int ret)
         standalone == 0 &&
 # endif
         chrooted == 0 && scoreboardfile != NULL) {
-# ifndef HAVE_SYS_FSUID_H        
+# ifndef NON_ROOT_FTP
+#  ifndef HAVE_SYS_FSUID_H        
         (void) seteuid((uid_t) 0);
-# else
+#  else
         (void) setfsuid((uid_t) 0);
+#  endif
 # endif
         (void) unlink(scoreboardfile);
     }
@@ -99,9 +101,11 @@ int ftpwho_initwho(void)
             return -1;
         }
     } else {        
-        if (fstat(fd, &st) != 0 || !S_ISDIR(st.st_mode)
-#ifndef NON_ROOT_FTP
-            || st.st_uid != (uid_t) 0
+        if (fstat(fd, &st) != 0 || !S_ISDIR(st.st_mode) ||
+#ifdef NON_ROOT_FTP
+            st.st_uid != geteuid()
+#else
+            st.st_uid != (uid_t) 0
 #endif
             ) {
             close(fd);
@@ -138,9 +142,11 @@ int ftpwho_initwho(void)
         goto err;
     }
     if (fstat(mmap_fd, &st) != 0 || !S_ISREG(st.st_mode) ||
-        (st.st_mode & 0600) != 0600 
-#ifndef NON_ROOT_FTP
-        || st.st_uid != (uid_t) 0
+        (st.st_mode & 0600) != 0600 ||
+#ifdef NON_ROOT_FTP
+        st.st_uid != geteuid()
+#else
+        st.st_uid != (uid_t) 0
 #endif
         ) {
         err2:
