@@ -1,6 +1,5 @@
 
 /* LDAP posixAccount handler for Pure-FTPd */
-/* (C)opyleft 2001-2002 by Frank DENIS <j@pureftpd.org> */
 
 #include <config.h>
 
@@ -196,24 +195,48 @@ static int pw_ldap_validate_name(const char *name)
     return 0;
 }
 
-static struct passwd *pw_ldap_getpwnam(const char *name)
+static struct passwd *pw_ldap_getpwnam(const char *name, 
+				       AuthResult * const result)
 {
     static struct passwd pwret;
     LDAP *ld;
     LDAPMessage *res;
     char *attrs[] = {                  /* OpenLDAP forgot a 'const' ... */
-        LDAP_UIDNUMBER, LDAP_GIDNUMBER, LDAP_HOMEDIRECTORY,
-            LDAP_USERPASSWORD, LDAP_LOGINSHELL, NULL
+        LDAP_UIDNUMBER, LDAP_FTPUID, LDAP_GIDNUMBER, LDAP_FTPGID,
+        LDAP_HOMEDIRECTORY, LDAP_USERPASSWORD, LDAP_LOGINSHELL, LDAP_FTPSTATUS,
+#ifdef QUOTAS
+	LDAP_QUOTAFILES, LDAP_QUOTAMBYTES,
+#endif
+#ifdef RATIOS
+	LDAP_DOWNLOADRATIO, LDAP_UPLOADRATIO,
+#endif
+#ifdef THROTTLING
+	LDAP_DOWNLOADBANDWIDTH, LDAP_UPLOADBANDWIDTH, 
+#endif
+	NULL
     };
     const char *pw_uid_s = NULL;
     const char *pw_gid_s = NULL;
     const char *pw_passwd_ldap = NULL;
+    const char *pw_enabled = NULL;
+#ifdef QUOTAS
+    const char *quota_files = NULL;
+    const char *quota_mbytes = NULL;
+#endif
+#ifdef RATIOS
+    const char *ratio_ul = NULL;
+    const char *ratio_dl = NULL;
+#endif
+#ifdef THROTTLING
+    const char *bandwidth_ul = NULL;
+    const char *bandwidth_dl = NULL;
+#endif
 
     memset(&pwret, 0, sizeof pwret);
     pwret.pw_name = pwret.pw_passwd = pwret.pw_gecos = pwret.pw_dir =
         pwret.pw_shell = NULL;
-    pwret.pw_uid = (uid_t) -1;
-    pwret.pw_gid = (gid_t) -1;    
+    pwret.pw_uid = (uid_t) 0;
+    pwret.pw_gid = (gid_t) 0;    
     if (pw_ldap_validate_name(name) != 0) {
         return NULL;
     }
@@ -225,6 +248,67 @@ static struct passwd *pw_ldap_getpwnam(const char *name)
     }
     pw_ldap_getpwnam_freefields(&pwret);    
     pwret.pw_name = (char *) name;
+    pw_enabled = pw_ldap_getvalue(ld, res, LDAP_FTPSTATUS);
+    if ((pw_enabled != NULL) && (strcasecmp(pw_enabled, "enabled") != 0)) {
+	goto error;
+    }
+#ifdef QUOTAS
+    if ((quota_files = pw_ldap_getvalue(ld, res, LDAP_QUOTAFILES)) != NULL) {
+	const unsigned long long q = strtoull(quota_files, NULL, 10);
+
+	if (q > 0ULL) {
+	    result->user_quota_files = q;
+	    result->quota_files_changed = 1;
+	}
+    }
+    if ((quota_mbytes = pw_ldap_getvalue(ld, res, LDAP_QUOTAMBYTES)) 
+	!= NULL) {
+	const unsigned long long q = strtoull(quota_mbytes, NULL, 10);
+	
+	if (q > 0ULL) {
+	    result->user_quota_size = q * (1024UL * 1024UL);
+	    result->quota_size_changed = 1;
+	}
+    }
+#endif    
+#ifdef RATIOS
+    if ((ratio_dl = pw_ldap_getvalue(ld, res, LDAP_DOWNLOADRATIO)) != NULL) {
+	const unsigned int q = strtoul(ratio_dl, NULL, 10);
+
+	if (q > 0U) {
+	    result->ratio_download = q;
+	    result->ratio_dl_changed = 1;
+	}
+    }
+    if ((ratio_ul = pw_ldap_getvalue(ld, res, LDAP_UPLOADRATIO)) != NULL) { 
+	const unsigned int q = strtoul(ratio_ul, NULL, 10);
+	
+	if (q > 0U) {
+	    result->ratio_upload = q;
+	    result->ratio_ul_changed = 1;
+	}
+    }
+#endif
+#ifdef THROTTLING
+    if ((bandwidth_dl = pw_ldap_getvalue(ld, res, LDAP_DOWNLOADBANDWIDTH)) 
+	!= NULL) {
+	const unsigned long q = (unsigned long) strtoul(bandwidth_dl, NULL, 10);
+
+	if (q > 0UL) {
+	    result->throttling_bandwidth_dl = q * 1024UL;
+	    result->throttling_dl_changed = 1;
+	}
+    }
+    if ((bandwidth_ul = pw_ldap_getvalue(ld, res, LDAP_UPLOADBANDWIDTH)) 
+	!= NULL) {
+	const unsigned long q = (unsigned long) strtoul(bandwidth_ul, NULL, 10);
+
+	if (q > 0UL) {
+	    result->throttling_bandwidth_ul = q * 1024UL;
+	    result->throttling_ul_changed = 1;
+	}
+    }
+#endif
     if ((pw_passwd_ldap =
          pw_ldap_getvalue(ld, res, LDAP_USERPASSWORD)) == NULL) {
         goto error;
@@ -234,20 +318,36 @@ static struct passwd *pw_ldap_getpwnam(const char *name)
         goto error;
     }
     free((void *) pw_passwd_ldap);
-    pw_passwd_ldap = NULL;    
-    if ((pw_uid_s = pw_ldap_getvalue(ld, res, LDAP_UIDNUMBER)) == NULL ||
+    pw_passwd_ldap = NULL;
+    if ((pw_uid_s = pw_ldap_getvalue(ld, res, LDAP_FTPUID)) == NULL ||
         *pw_uid_s == 0 || 
         (pwret.pw_uid = (uid_t) strtoul(pw_uid_s, NULL, 10)) <= (uid_t) 0) {
-        pwret.pw_uid = default_uid;
-    } 
+        if (pw_uid_s != NULL) {
+            free((void *) pw_uid_s);
+            pw_uid_s = NULL;
+        }
+        if ((pw_uid_s = pw_ldap_getvalue(ld, res, LDAP_UIDNUMBER)) == NULL ||
+            *pw_uid_s == 0 || 
+            (pwret.pw_uid = (uid_t) strtoul(pw_uid_s, NULL, 10)) <= (uid_t) 0) {
+            pwret.pw_uid = default_uid;
+        }                 
+    }     
     if (pw_uid_s != NULL) {
         free((void *) pw_uid_s);
         pw_uid_s = NULL;
     }
-    if ((pw_gid_s = pw_ldap_getvalue(ld, res, LDAP_GIDNUMBER)) == NULL ||
+    if ((pw_gid_s = pw_ldap_getvalue(ld, res, LDAP_FTPGID)) == NULL ||
         *pw_gid_s == 0 ||
         (pwret.pw_gid = (gid_t) strtoul(pw_gid_s, NULL, 10)) <= (gid_t) 0) {
-        pwret.pw_gid = default_gid;
+        if (pw_gid_s != NULL) {
+            free((void *) pw_gid_s);
+            pw_gid_s = NULL;
+        }
+        if ((pw_gid_s = pw_ldap_getvalue(ld, res, LDAP_GIDNUMBER)) == NULL ||
+            *pw_gid_s == 0 ||
+            (pwret.pw_gid = (gid_t) strtoul(pw_gid_s, NULL, 10)) <= (gid_t) 0) {
+            pwret.pw_gid = default_gid;
+        }                        
     } 
     if (pw_gid_s != NULL) {
         free((void *) pw_gid_s);
@@ -283,7 +383,33 @@ static struct passwd *pw_ldap_getpwnam(const char *name)
     if (pw_passwd_ldap != NULL) {
         free((void *) pw_passwd_ldap);
     }    
-
+    if (pw_enabled != NULL) {
+	free((void *) pw_enabled);
+    }
+#ifdef QUOTAS
+    if (quota_files != NULL) {
+	free((void *) quota_files);
+    }
+    if (quota_mbytes != NULL) {
+	free((void *) quota_mbytes);
+    }
+#endif
+#ifdef RATIOS
+    if (ratio_ul != NULL) {
+	free((void *) ratio_ul);
+    }
+    if (ratio_dl != NULL) {
+	free((void *) ratio_dl);
+    }
+#endif
+#ifdef THROTTLING
+    if (bandwidth_ul != NULL) {
+	free((void *) bandwidth_ul);
+    }
+    if (bandwidth_dl != NULL) {
+	free((void *) bandwidth_dl);
+    }
+#endif
     return NULL;
 }
 
@@ -301,7 +427,7 @@ void pw_ldap_check(AuthResult * const result,
     (void) peer;
     result->auth_ok = 0;
     if (account == NULL || *account == 0 || password == NULL ||
-        (pw = pw_ldap_getpwnam(account)) == NULL) {
+        (pw = pw_ldap_getpwnam(account, result)) == NULL) {
         return;
     }
     result->auth_ok--;                  /* -1 */
@@ -350,7 +476,7 @@ void pw_ldap_check(AuthResult * const result,
     }    
     result->uid = pw->pw_uid;
     result->gid = pw->pw_gid;
-    if (result->uid == (uid_t) 0 || result->gid == (gid_t) 0) {
+    if (result->uid <= (uid_t) 0 || result->gid <= (gid_t) 0) {
         return;
     }
     if ((result->dir = strdup(pw->pw_dir)) == NULL) {
