@@ -143,7 +143,7 @@
 #define MSG_TYPE_UNKNOWN "Unknown TYPE"
 #define MSG_TYPE_SUCCESS "TYPE is now"
 #define MSG_STRU_FAILURE "Only F(ile) is supported"
-#define MSG_MODE_FAILURE "Please us S(tream) mode"
+#define MSG_MODE_FAILURE "Please use S(tream) mode"
 #define MSG_RENAME_ABORT "Aborting previous rename operation"
 #define MSG_RENAME_RNFR_SUCCESS "RNFR accepted - file exists, ready for destination"
 #define MSG_FILE_DOESNT_EXIST "Sorry, but that file doesn't exist"
@@ -172,7 +172,7 @@
 #define MSG_NEW_CONNECTION "New connection from %s"
 #define MSG_WELCOME_TO "Welcome to"
 #define MSG_MAX_USERS "%lu users (the maximum) are already logged in, sorry"
-#define MSG_NB_USERS "You are user number %d of %d allowed"
+#define MSG_NB_USERS "You are user number %d of %d allowed."
 #define MSG_WELCOME_TIME "Local time is now %02d:%02d and the load is %3.2f. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Only anonymous FTP is allowed here"
 #define MSG_RATIOS_EVERYONE "RATIOS ARE ENABLED FOR EVERYONE:"
@@ -213,3 +213,5 @@
 #define MSG_ALIASES_UNKNOWN "Unknown alias %s."
 #define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
 #define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_PERUSER_MAX "I can't accept more than %lu connections as the same user"
+#define MSG_IPV6_OK "IPv6 connections are also welcome on this server."
