@@ -172,7 +172,7 @@
 #define MSG_NEW_CONNECTION "%s ramene son cul"
 #define MSG_WELCOME_TO "C'est de la bonne:"
 #define MSG_MAX_USERS "%lu relous (le maximum) sont deja connectes, degage"
-#define MSG_NB_USERS "T'es le numero %d sur les %d max"
+#define MSG_NB_USERS "T'es le numero %d sur les %d max."
 #define MSG_WELCOME_TIME "L'heure locale est %02d:%02d et la charge courante est de %3.2f. Port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Je prend que les mecs anonymes"
 #define MSG_RATIOS_EVERYONE "Y A DES RATIOS POUR TOUS LES UTILISATEURS:"
@@ -213,3 +213,5 @@
 #define MSG_ALIASES_UNKNOWN "Je connais pas %s."
 #define MSG_ALIASES_BROKEN_FILE "Ahahah gros naze, ton fichier d'alias est tout pourrave"
 #define MSG_ALIASES_LIST "Si t'as la flemme, tu peux utiliser ces raccourcis :"
+#define MSG_PERUSER_MAX "T'es deja la %lu fois, j'en ai marre de voir ta gueule"
+#define MSG_IPV6_OK "Si t'es pas un batard, tu peux te connecter en IPv6."
