@@ -7,9 +7,9 @@
 #define MSG_DEBUG_CLIENT_IS " ּҴ"
 #define MSG_SYNTAX_ERROR_IP "IP ּ   "
 #define MSG_PORT_SUCCESSFUL "PORT  "
-#define MSG_ONLY_IPV4V6 "IPv4  IPv6  "
-#define MSG_ONLY_IPV4 "IPv4  "
-#define MSG_TIMEOUT_PARSER "ðʰ"
+#define MSG_ONLY_IPV4V6 "IPv4  IPv6   (1,2)"
+#define MSG_ONLY_IPV4 "IPv4   (1)"
+#define MSG_TIMEOUT_PARSER "ð ʰ"
 #define MSG_LINE_TOO_LONG "ʹ "
 #define MSG_LOG_OVERFLOW "ڰ ɾ  overflow õ"
 #define MSG_GOODBYE "ȳ~ ε %llu / ٿε %llu kb"
@@ -42,7 +42,7 @@
 #define MSG_UNABLE_SECURE_ANON " anonymous FTP  Ұ"
 #define MSG_BANDWIDTH_RESTRICTED "뿪 ѵǾ ֽϴ."
 #define MSG_NO_PASSWORD_NEEDED "ƹ нε α "
-#define MSG_NOTRUST "˼մϴٸ,   ."
+#define MSG_NOTRUST "˼մϴٸ,    ."
 #define MSG_WHOAREYOU " Ű?"
 #define MSG_AUTH_FAILED " "
 #define MSG_AUTH_TOOMANY "ݺ  "
@@ -51,7 +51,7 @@
 #define MSG_START_SLASH "/  "
 #define MSG_USER_GROUP_ACCESS " %s   ׷쿡  "
 #define MSG_FXP_SUPPORT "  FXP  밡 մϴ."
-#define MSG_RATIO "ٿ/ε ( %u:%u )  ּ."
+#define MSG_RATIO "/ٿε ( %u:%u )  ּ."
 #define MSG_CHROOT_FAILED "chroot()  Ҽ "
 #define MSG_CURRENT_DIR_IS " 丮: %s"
 #define MSG_CURRENT_RESTRICTED_DIR_IS "ѵ 丮 %s"
@@ -107,7 +107,7 @@
     "˼մϴ.  /ٿ  %u:%u Դϴ.\n" \
 	 " %llu Kb  εϰ %llu Kb ٿε Ͽϴ.\n" \
     "  ε ּ."
-#define MSG_NO_MORE_TO_DOWNLOAD "ٿεҼ "
+#define MSG_NO_MORE_TO_DOWNLOAD "ٿε   "
 #define MSG_WINNER "ǻʹ  ģ̴ Ͼ߸ մϴ!"
 #define MSG_KBYTES_LEFT "%.1f kb ٿε"
 #define MSG_ABORTED " "
@@ -213,3 +213,5 @@
 #define MSG_ALIASES_UNKNOWN "   Ī %s."
 #define MSG_ALIASES_BROKEN_FILE "ջ Ī "
 #define MSG_ALIASES_LIST " Ī  :"
+#define MSG_PERUSER_MAX "  %lu  ̻   ʽϴ."
+#define MSG_IPV6_OK "  IPv6 ᵵ մϴ."
