@@ -205,11 +205,13 @@
 #define MSG_SQL_DOWN "SQL servern frefaller vara nere"
 #define MSG_ILLEGAL_QUOTA "Ogiltig kvot"
 #define MSG_QUOTA_FILES "%llu filer anvnda (%d%%) - authorized: %llu files"
-#define MSG_QUOTA_SIZE "%llu Kbytes used (%d%%) - authorized: %llu Kb"
+#define MSG_QUOTA_SIZE "%llu Kbytes anvnda (%d%%) - Tilltet: %llu Kb"
 #define MSG_QUOTA_EXCEEDED "Kvoten verskriden: %s kommer inte att sparas"
 #define MSG_AUTH_UNKNOWN "Oknd behrighetskontroll"
 #define MSG_PDB_BROKEN "Kan ej lsa den indexerade puredb filen (eller gammalt format) - Frsk med pure-pw mkdb"
-#define MSG_ALIASES_ALIAS "%s is an alias for %s."
-#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
-#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
-#define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_ALIASES_ALIAS "%s r ett alias fr %s."
+#define MSG_ALIASES_UNKNOWN "Oknt alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Skadad alias fil"
+#define MSG_ALIASES_LIST "Fljande alias r tillgngliga :"
+#define MSG_PERUSER_MAX "Jag kan inte acceptera fler n %lu anslutningar frn en och samma anvndare"
+#define MSG_IPV6_OK "IPv6 anslutningar r ocks vlkomna till denna server"
