@@ -17,9 +17,6 @@
 # ifndef WIFEXITED
 #  define WIFEXITED(st) (((st) & 0xff) == 0)
 # endif
-# ifdef WITH_DMALLOC
-#  include <dmalloc.h>
-# endif
 
 #ifndef WHOMAXLEN
 # define WHOMAXLEN 127
